@@ -12,7 +12,7 @@ if [ -f "/.filebrowser.json" ]; then
   echo ""
   echo "The volume mount configuration has changed in the latest release."
   echo "Please rename .filebrowser.json to settings.json and mount the parent directory to /config".
-  echo "Read more on https://github.com/filebrowser/filebrowser/blob/master/docs/installation.md#docker"
+  echo "Read more on https://filebrowser.org/installation.html#docker"
   echo ""
   echo "This workaround will be removed in a future release."
   echo ""
@@ -27,7 +27,7 @@ if [ -f "/database.db" ]; then
   echo ""
   echo "The volume mount configuration has changed in the latest release."
   echo "Please rename database.db to filebrowser.db and mount the parent directory to /database".
-  echo "Read more on https://github.com/filebrowser/filebrowser/blob/master/docs/installation.md#docker"
+  echo "Read more on https://filebrowser.org/installation.html#docker"
   echo ""
   echo "This workaround will be removed in a future release."
   echo ""
